==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2transitgateway/kotlin/inputs/GetPeeringAttachmentFilter.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2transitgateway.kotlin.inputs

import com.pulumi.aws.ec2transitgateway.inputs.GetPeeringAttachmentFilter.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the field to filter by, as defined by
 * [the underlying AWS API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayPeeringAttachments.html).
 * @property values Set of values that are accepted for the given field.
 * An EC2 Transit Gateway Peering Attachment be selected if any one of the given values matches.
 */
public data class GetPeeringAttachmentFilter(
    public val name: String,
    public val values: List<String>,
) : ConvertibleToJava<com.pulumi.aws.ec2transitgateway.inputs.GetPeeringAttachmentFilter> {
    override fun toJava(): com.pulumi.aws.ec2transitgateway.inputs.GetPeeringAttachmentFilter =
        com.pulumi.aws.ec2transitgateway.inputs.GetPeeringAttachmentFilter.builder()
            .name(name.let({ args0 -> args0 }))
            .values(values.let({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [GetPeeringAttachmentFilter].
 */
@PulumiTagMarker
public class GetPeeringAttachmentFilterBuilder internal constructor() {
    private var name: String? = null

    private var values: List<String>? = null

    /**
     * @param value Name of the field to filter by, as defined by
     * [the underlying AWS API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayPeeringAttachments.html).
     */
    @JvmName("nctarxkqivfbcadm")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Set of values that are accepted for the given field.
     * An EC2 Transit Gateway Peering Attachment be selected if any one of the given values matches.
     */
    @JvmName("ropofixmxkrlfuom")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    /**
     * @param values Set of values that are accepted for the given field.
     * An EC2 Transit Gateway Peering Attachment be selected if any one of the given values matches.
     */
    @JvmName("jvidqpcsqvugnnfm")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    internal fun build(): GetPeeringAttachmentFilter = GetPeeringAttachmentFilter(
        name = name ?: throw PulumiNullFieldException("name"),
        values = values ?: throw PulumiNullFieldException("values"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2transitgateway/kotlin/inputs/GetPeeringAttachmentFilter.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2transitgateway.kotlin.inputs

import com.pulumi.aws.ec2transitgateway.inputs.GetPeeringAttachmentFilter.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the field to filter by, as defined by
 * [the underlying AWS API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayPeeringAttachments.html).
 * @property values Set of values that are accepted for the given field.
 * An EC2 Transit Gateway Peering Attachment be selected if any one of the given values matches.
 */
public data class GetPeeringAttachmentFilter(
    public val name: String,
    public val values: List<String>,
) : ConvertibleToJava<com.pulumi.aws.ec2transitgateway.inputs.GetPeeringAttachmentFilter> {
    override fun toJava(): com.pulumi.aws.ec2transitgateway.inputs.GetPeeringAttachmentFilter =
        com.pulumi.aws.ec2transitgateway.inputs.GetPeeringAttachmentFilter.builder()
            .name(name.let({ args0 -> args0 }))
            .values(values.let({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [GetPeeringAttachmentFilter].
 */
@PulumiTagMarker
public class GetPeeringAttachmentFilterBuilder internal constructor() {
    private var name: String? = null

    private var values: List<String>? = null

    /**
     * @param value Name of the field to filter by, as defined by
     * [the underlying AWS API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayPeeringAttachments.html).
     */
    @JvmName("htnscwkiuontabpp")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Set of values that are accepted for the given field.
     * An EC2 Transit Gateway Peering Attachment be selected if any one of the given values matches.
     */
    @JvmName("ertgbsxdmkvakgyq")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    /**
     * @param values Set of values that are accepted for the given field.
     * An EC2 Transit Gateway Peering Attachment be selected if any one of the given values matches.
     */
    @JvmName("nosrpdijnetrdhoq")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.values = mapped
    }

    internal fun build(): GetPeeringAttachmentFilter = GetPeeringAttachmentFilter(
        name = name ?: throw PulumiNullFieldException("name"),
        values = values ?: throw PulumiNullFieldException("values"),
    )
}
